@@ -23,12 +23,17 @@ if( !isset($gCms) ) exit;
 global $gCms;
 $db =& $gCms->GetDB();
 
+$this->SetPreference('visual_framework', (string) $params['input_visual_framework']);
 $this->SetPreference('buggy_gmp', (int) $params['input_buggy_gmp']);
 $this->SetPreference('use_insecure_rand', (int) $params['input_insecure_rand']);
 $this->SetPreference('ca_file_override', (int) $params['input_ca_file_override']);
 $this->SetPreference('enable_debugging', (int) $params['input_debugging']);
 $this->SetPreference('facebook_app_id', (string) $params['input_facebook_app_id']);
 $this->SetPreference('facebook_app_secret', (string) $params['input_facebook_app_secret']);
+$this->SetPreference('twitter_consumer_key', (string) $params['input_twitter_consumer_key']);
+$this->SetPreference('twitter_consumer_secret', (string) $params['input_twitter_consumer_secret']);
+$this->SetPreference('login_redirect', (string) $params['input_login_redirect']);
+$this->SetPreference('login_redirect_pageid', (string) $params['input_login_redirect_pageid']);
 
 include(dirname(__FILE__) . '/action.defaultadmin.php');
 
