@@ -24,22 +24,36 @@ global $gCms;
 
 $smarty =& $gCms->GetSmarty();
 $startform = $this->CreateFormStart($id, 'login', $returnid, 'post');
-$startform = str_replace('class="', 'class="openid ', $startform);
+$startform = str_replace('class="', 'class="openid_form ', $startform);
 $smarty->assign('startform', $startform);
 
-$smarty->assign('facebookLoginUrl', $this->FacebookLoginUrl($id, 'facebook', $returnid));
+$facebookLoginUrl = $this->FacebookLoginUrl($id, 'facebook', $returnid);
+$twitterLoginUrl = $this->CreateLink($id, 'twitter_login', $returnid, null, null, null, true, true, null, null);
 $config = $gCms->GetConfig();
 $smarty->assign('root_path', $config['root_path']);
 
 /* @var $feu FrontEndUsers */
 $feu = $this->GetModuleInstance('FrontEndUsers');
 if (!$feu->LoggedIn()) {
-    echo $this->ProcessTemplate('login_form.tpl');
+    if ($this->GetPreference('visual_framework', 'jqueryplugin') == 'jqueryplugin') {
+        $smarty->assign('facebookLoginUrl', $facebookLoginUrl);
+        $smarty->assign('twitterLoginUrl', $twitterLoginUrl);
+        echo $this->ProcessTemplate('login_form.tpl');
+    } else {
+        // Replace encoded ampersands since javascripts doesn't understand &amp;
+        // XHTML support solved by CDATA tags inside the script tag
+        $smarty->assign('facebookLoginUrl', str_replace('&amp;', '&', $facebookLoginUrl));
+        $smarty->assign('twitterLoginUrl', str_replace('&amp;', '&', $twitterLoginUrl));
+        echo $this->ProcessTemplate('login_form_openid_selector.tpl');
+    }
 } else {
+    $smarty->assign('facebookLoginUrl', $facebookLoginUrl);
+    $smarty->assign('twitterLoginUrl', $twitterLoginUrl);
     $registeredOpenIDs = $this->GetRegisteredOpenIDs();
     if (empty($registeredOpenIDs)) {
         echo $this->ProcessTemplate('register_provider.tpl');
     } else {
+        $smarty->assign('remove_link', $this->CreateLink($id, 'remove', $returnid, null, null, null, true, false, null, null));
         echo $this->ProcessTemplate('list_providers.tpl');
     }
 }
